@@ -7,6 +7,7 @@ Copyright (c) 2009-2017 Exa Networks. All rights reserved.
 License: 3-clause BSD. (See the COPYRIGHT file)
 """
 
+from operator import eq
 import os
 import sys
 import stat
@@ -192,8 +193,8 @@ def main():
     else:
         decode = ''
 
-    duration = options["--signal"]
-    if duration and duration.isdigit():
+    if options["--signal"] and options["--signal"].isdigit():
+        duration = options["--signal"]
         pid = os.fork()
         if pid:
             import time
