@@ -15,10 +15,10 @@ To use, declare this program as a process in your
        peer-as 64497;
     }
     process watch-haproxy {
-       run exabgp-healthcheck --cmd "curl -sf http://127.0.0.1/healthcheck" --label haproxy;
+       run python -m exabgp healthcheck --cmd "curl -sf http://127.0.0.1/healthcheck" --label haproxy;
     }
     process watch-mysql {
-       run exabgp-healthcheck --cmd "mysql -u check -e 'SELECT 1'" --label mysql;
+       run python -m exabgp healthcheck --cmd "mysql -u check -e 'SELECT 1'" --label mysql;
     }
 
 Use :option:`--help` to get options accepted by this program. A
@@ -222,7 +222,7 @@ def parse():
         help=("Instead of increasing the metric on health failure, " "withdraw the route"),
     )
     g.add_argument("--path-id", metavar='PATHID', type=int, default=None, help="path ID to advertise for the route")
-    g.add_argument("--neighbor", metavar='NEIGHBOR', type=ip_address, dest="neighbors", action="append", help="advertise the route to the selected neigbors")
+    g.add_argument("--neighbor", metavar='NEIGHBOR', type=str, dest="neighbors", action="append", help="advertise the route to the selected neigbors")
 
     g = parser.add_argument_group("reporting")
     g.add_argument("--execute", metavar='CMD', type=str, action="append", help="execute CMD on state change")
@@ -269,8 +269,6 @@ def setup_logging(debug, silent, name, syslog_facility, syslog):
             return "/var/run/log"
         if sys.platform.startswith("netbsd"):
             return "/var/run/log"
-        if sys.platform.startswith("openbsd"):
-            return "/dev/log"
         if sys.platform.startswith("linux"):
             return "/dev/log"
         raise EnvironmentError("Unable to guess syslog address for your " "platform, try to disable syslog")
@@ -490,12 +488,12 @@ def loop(options):
             as_path = options.as_path
         for ip in options.ips:
             if options.withdraw_on_down or target is states.EXIT:
-                command = "announce" if target is states.UP else "withdraw"
+                command = "neighbor * announce" if target is states.UP else "neighbor * withdraw"
             else:
-                command = "announce"
+                command = "neighbor * announce"
             announce = "route {0} next-hop {1}".format(str(ip), options.next_hop or "self")
 
-            if command == "announce":
+            if command == "neighbor * announce":
                 announce = "{0} med {1}".format(announce, metric)
                 if options.local_preference >= 0:
                     announce = "{0} local-preference {1}".format(announce, options.local_preference)
