@@ -34,6 +34,11 @@ class ICMPType(Resource):
     MASK_REQUEST = 0x11
     MASK_REPLY = 0x12
     TRACEROUTE = 0x1E
+    EXPERIMENTAL_MOBILITY = 0x29
+    EXTENDED_ECHO_REQUEST = 0x2A
+    EXTENDED_ECHO_REPLY = 0x2B
+    EXPERIMENTAL_ONE = 0xFD
+    EXPERIMENTAL_TWO = 0xFE
 
     codes = dict(
         (k.lower().replace('_', '-'), v)
@@ -54,6 +59,11 @@ class ICMPType(Resource):
             'MASK_REQUEST': MASK_REQUEST,
             'MASK_REPLY': MASK_REPLY,
             'TRACEROUTE': TRACEROUTE,
+            'EXPERIMENTAL_MOBILITY': EXPERIMENTAL_MOBILITY,
+            'EXTENDED_ECHO_REQUEST': EXTENDED_ECHO_REQUEST,
+            'EXTENDED_ECHO_REPLY': EXTENDED_ECHO_REPLY,
+            'EXPERIMENTAL_ONE': EXPERIMENTAL_ONE,
+            'EXPERIMENTAL_TWO': EXPERIMENTAL_TWO,
         }.items()
     )
 
